==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebChipDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentBoolValueChangedEventArgsDescriptionMetadata } from "./WebComponentBoolValueChangedEventArgsDescriptionMetadata";
import { WebChipDescription } from "./WebChipDescription";
/**
 * @hidden
 */
var WebChipDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebChipDescriptionMetadata, _super);
    function WebChipDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebChipDescriptionMetadata.b = function (a) {
        if (WebChipDescriptionMetadata.a == null) {
            WebChipDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebChipDescriptionMetadata.c(WebChipDescriptionMetadata.a);
        }
        if (a.g(WebChipDescriptionMetadata.a)) {
            return;
        }
        a.s(WebChipDescriptionMetadata.a);
        WebComponentBoolValueChangedEventArgsDescriptionMetadata.d(a);
    };
    WebChipDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Chip");
        a.item("Disabled", "Boolean");
        a.item("Removable", "Boolean");
        a.item("Selectable", "Boolean");
        a.item("Selected", "Boolean");
        a.item("Variant", "ExportedType:string:ChipVariant");
        a.item("Variant@names", "Primary;Info;Success;Warning;Danger");
        a.item("Size", "ExportedType:string:SizableComponentSize");
        a.item("Size@names", "Large;Small;Medium");
        a.item("RemoveRef", "EventRef::remove");
        a.item("SelectRef", "EventRef::select");
    };
    WebChipDescriptionMetadata.d = function (a) {
        WebChipDescriptionMetadata.b(a);
        a.u("WebChip", function () { return new WebChipDescription(); });
        a.t("WebChip", WebChipDescriptionMetadata.a);
    };
    WebChipDescriptionMetadata.$t = markType(WebChipDescriptionMetadata, 'WebChipDescriptionMetadata');
    WebChipDescriptionMetadata.a = null;
    return WebChipDescriptionMetadata;
}(Base));
export { WebChipDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebChipDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentBoolValueChangedEventArgsDescriptionMetadata } from "./WebComponentBoolValueChangedEventArgsDescriptionMetadata";
import { WebChipDescription } from "./WebChipDescription";
/**
 * @hidden
 */
var WebChipDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebChipDescriptionMetadata, _super);
    function WebChipDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebChipDescriptionMetadata.b = function (a) {
        if (WebChipDescriptionMetadata.a == null) {
            WebChipDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebChipDescriptionMetadata.c(WebChipDescriptionMetadata.a);
        }
        if (a.j(WebChipDescriptionMetadata.a)) {
            return;
        }
        a.y(WebChipDescriptionMetadata.a);
        WebComponentBoolValueChangedEventArgsDescriptionMetadata.d(a);
    };
    WebChipDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Chip");
        a.item("__tagNameWC", "String:igc-chip");
        a.item("Disabled", "Boolean");
        a.item("Removable", "Boolean");
        a.item("Selectable", "Boolean");
        a.item("Selected", "Boolean");
        a.item("Variant", "ExportedType:string:ChipVariant");
        a.item("Variant@names", "Primary;Info;Success;Warning;Danger");
        a.item("Size", "ExportedType:string:SizableComponentSize");
        a.item("Size@names", "Large;Small;Medium");
        a.item("RemoveRef", "EventRef::remove");
        a.item("SelectRef", "EventRef::select");
    };
    WebChipDescriptionMetadata.d = function (a) {
        WebChipDescriptionMetadata.b(a);
        a.aa("WebChip", function () { return new WebChipDescription(); });
        a.z("WebChip", WebChipDescriptionMetadata.a);
    };
    WebChipDescriptionMetadata.$t = markType(WebChipDescriptionMetadata, 'WebChipDescriptionMetadata');
    WebChipDescriptionMetadata.a = null;
    return WebChipDescriptionMetadata;
}(Base));
export { WebChipDescriptionMetadata };
